@@ -8,7 +8,7 @@ gi.require_version("Hkl", "5.0")
 # NOTE: MUST call gi.require_version() BEFORE import hkl
 from hkl.calc import A_KEV
 from hkl.diffract import Constraint
-from hkl.geometries import SimulatedE4CV
+from hkl import SimulatedE4CV
 
 
 class Fourc(SimulatedE4CV):
@@ -173,6 +173,8 @@ def test_forward_solutions_table(fourc):
     assert pytest.approx(sol.phi, 1e-5) == -90
     assert pytest.approx(sol.tth, 1e-5) == -60
 
+    fourc.apply_constraints({"tth": Constraint(0, 180, 0, True)})
+
     tbl = fourc.forward_solutions_table(
         # fmt: off
         [
@@ -286,7 +288,7 @@ def test_show_constraints(fourc, capsys):
     out = [v.rstrip() for v in out.strip().splitlines()]
     expected = [
         "===== ========= ========== ===== ====",
-        "axis  low_limit high_limit value fit ",
+        "axis  low_limit high_limit value fit",
         "===== ========= ========== ===== ====",
         "omega -180.0    180.0      0.0   True",
         "chi   -180.0    180.0      0.0   True",
@@ -313,3 +315,31 @@ def test_apply_constraints(fourc):
     assert pytest.approx(sol.chi, 1e-5) == 0
     assert pytest.approx(sol.phi, 1e-5) == 90
     assert pytest.approx(sol.tth, 1e-5) == 60
+
+
+def test_specify_engine():
+    import hkl
+    import numpy as np
+    from ophyd import Component as Cpt
+    from ophyd import PseudoSingle
+    from ophyd import SoftPositioner
+
+    class Q4C(hkl.E4CV):
+        q = Cpt(PseudoSingle, "")
+        omega = Cpt(SoftPositioner, limits=(-180, 180), init_pos=0)
+        chi = Cpt(SoftPositioner, limits=(-180, 180), init_pos=0)
+        phi = Cpt(SoftPositioner, limits=(-180, 180), init_pos=0)
+        tth = Cpt(SoftPositioner, limits=(-180, 180), init_pos=0)
+
+    q4c = Q4C("", name="q4c")
+    assert q4c.calc.engine.name == "hkl"
+
+    q4c = Q4C("", name="q4c", engine="q")
+    assert q4c.calc.engine.name == "q"
+    q = 1.0
+    angle = 2 * np.arcsin(q * q4c.calc.wavelength / 4 / np.pi) * 180 / np.pi
+    value = q4c.forward(q)
+    assert round(value.tth, 5) == round(angle, 5)
+    assert value.omega == 0.0
+    assert value.chi == 0.0
+    assert value.phi == 0.0
